@@ -6,10 +6,12 @@
 #'
 #' @export
 #'
-#' @param features Input features
+#' @param features Input features, as a [data-Feature] or
+#' [data-FeatureCollection]
+#' @param properties A list of properties. Default: `NULL`
 #' @template lint
 #' @family measurements
-#' @return Feature - centroid of the input features
+#' @return a [data-Feature]<([data-Point])> - centroid of the input features
 #' @examples
 #' poly <- '{
 #'   "type": "Feature",
@@ -26,9 +28,13 @@
 #'   }
 #' }'
 #' lawn_centroid(features = poly)
-lawn_centroid <- function(features, lint = FALSE) {
+#' lawn_centroid(features = as.feature(poly))
+#' lawn_centroid(features = poly, properties = list(foo = "bar"))
+lawn_centroid <- function(features, properties = NULL, lint = FALSE) {
   fts <- convert(features)
   lawnlint(fts, lint)
-  ct$eval(sprintf("var ctr = turf.centroid(%s);", fts))
+  assert(fts, c('character', 'feature', 'featurecollection', 'json'))
+  if (lint) is_type(fts, type_top = c("Feature", "FeatureCollection"))
+  ct$eval(sprintf("var ctr = turf.centroid(%s, %s);", fts, toj(properties)))
   structure(ct$get("ctr"), class = "point")
 }
